#Sinnesael et al., Anticosti Cyclo, Vaural Fm.
#
#This script documents the analyses that were carried out in the 'Astrochron' (Meyers, 2014) 
#package for R (R Core Team, ref).

#---INITIATION---

#load the 'astrochron package'
library(astrochron)

#load the data
data=read(d=0,h="no",srt=T,ave=T,genplot=F) #data=403-880

#Plot data
plot(data,type="l")

#linterp
data=linterp(data)

#lin, 1p detrend
data=detrend(data)

#---SPECTRAL ANALYSIS---
#periodogram-mtm
periodogram(data,xmax=0.5)
mtm(data,tbw=2,xmax=0.5,pl=1,output=0,siglevel=0.8)

#evolutionary - eha
EHA_output=eha(data,fmin=0.00,fmax=0.30,step=1,win=100,ydir=-1,output=3,xlab="test",ylab="test",genplot=2)

#---TIMEOPT---
# evaluate precession modulations
#targetP=c(20.3, 17.15) #Waltham, 2015
#targetP=c(19.25,16.34) #Berger et al., 1992
#targetE=c(405,130,123,98,94)
targetE=c(405,125,95)
targetP=c(20.8,19.8,17.2,17.1)


#---TimeOpt
timeOpt(data,sedmin=20,sedmax=80,targetP=targetP,targetE=targetE,numsed=100,fit=1,output=0)

#---eTimeOpt
res=eTimeOpt(data,win=100,step=2,sedmin=10,sedmax=90,numsed=50,limit=F,fit=1,targetP=targetP,output=1,ydir=-1)

sedrates=eTimeOptTrack(res[2])

writeT("SR_eTimeOpt.tab",sedrates)

#---timeOptTemplate
template=data
template[2]=data[1]

#precession amplitude
outputSR20_60=timeOptTemplate(data,template=template,sedmin=20,sedmax=60,difmin=10,difmax=70,numsed=50,
                           fit=1,targetP=targetP,targetE=targetE,flipTemplate=F,ncores=4,output=1,iopt=3)
#eccentricity amplitude
output2=timeOptTemplate(data,template=template,sedmin=20,sedmax=60,difmin=10,difmax=70,numsed=50,
                       fit=2,targetP=targetP,targetE=targetE,flipTemplate=F,ncores=4,output=2,iopt=1)




